
```python
{{ code_context }}
```

You are required to write test for the following classes or functions using pytest. You may find the docstrings useful for illustrating the use case of the function or class.

```python 
```

{% if existing_context|length > 0 %}

These are the tests and fixtures that are already available in the test script for your reference.

```python
{{ existing_context }}
```

{% endif %}

You should define pytest fixture for dummy data when appropriate.
Most importantly, return only Python code, nothing but the Python code. No explanation needed.